#
# Dungeon game main program.
# Reads in the dungeon configuration from standard input.
# Usage:
#  python DungeonGame.py d0.txt
#  
# ##### DO NOT MODIFY THIS FILE #### 
#  
# Author Keith Vertanen
# Author Michele Van Dyne - file input modifications
#                         - 11/12/19 - ported to python
#

from Config import Config
from Dungeon import Dungeon
from Hero import Hero
from Item import Item
import sys
import StdDraw

#
# Program for the game control and game loop
# 
# param: args file name for the configuration file
#             files provided are d0.txt, d1.txt, d2.txt
#

config = Config()
with open(sys.argv[1], 'r') as file:
    
    # Read in the size and number of keys/gems
    line = file.readline().split()
    width   = int(line[0])
    height  = int(line[1])
    line = file.readline().split()
    numKeys = int(line[0])
    numGems = int(line[1])

    # Prepare the standard draw window
    StdDraw.setCanvasSize(config.cellPixels() * width, config.cellPixels() * height)
    StdDraw.setXscale(0.0, config.cellPixels() * width)
    StdDraw.setYscale(0.0, config.cellPixels() * height)

    # Construct the dungeon layout
    dungeon = Dungeon(config, width, height)

    # Read in the initial location of the hero
    line = file.readline().split()
    heroX = int(line[0])
    heroY = int(line[1])
    hero = Hero(config, heroX, heroY)
    dungeon.addHero(hero)

    # Setup all the cells in the dungeon
    for y in range(0, height):
        line = file.readline().split()
        for x in range(0, width):
            dungeon.set(x, height - y - 1, line[x]) 
    file.close()

# Add the right number of keys and gems at random locations
for i in range(0, numKeys):
    dungeon.addItem(Item.KEY)
for i in range(0, numGems):
    dungeon.addItem(Item.GEM)

dungeon.draw()

while True:
    if StdDraw.hasNextKeyTyped():
        action = config.mapKeyToAction(StdDraw.nextKeyTyped())
        dungeon.execute(action)
        dungeon.draw()
    StdDraw.show(100)
